@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Dump;
 
-our $DATE = '2014-12-21'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-07-30'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010;
 use strict;
@@ -43,8 +43,9 @@ _
     args => {
         filename => {
             summary => 'Path to the script',
-            req => 1,
             schema => 'str*',
+            req => 1,
+            pos => 0,
         },
         libs => {
             summary => 'Libraries to unshift to @INC when running script',
@@ -64,8 +65,8 @@ sub dump_perinci_cmdline_script {
     my $detres = Perinci::CmdLine::Util::detect_perinci_cmdline_script(
         filename => $filename);
     return $detres if $detres->[0] != 200;
-    return [412, "File '$filename' is not script using Perinci::CmdLine"]
-        unless $detres->[2];
+    return [412, "File '$filename' is not script using Perinci::CmdLine (".
+        $detres->[3]{'func.reason'}.")"] unless $detres->[2];
 
     my $libs = $args{libs} // [];
 
@@ -138,15 +139,16 @@ Perinci::CmdLine::Dump - Run a Perinci::CmdLine-based script but only to dump th
 
 =head1 VERSION
 
-This document describes version 0.02 of Perinci::CmdLine::Dump (from Perl distribution Perinci-CmdLine-Dump), released on 2014-12-21.
+This document describes version 0.03 of Perinci::CmdLine::Dump (from Perl distribution Perinci-CmdLine-Dump), released on 2015-07-30.
 
 =head1 FUNCTIONS
 
 
 =head2 dump_perinci_cmdline_script(%args) -> [status, msg, result, meta]
 
-Run a Perinci::CmdLine-based script but only to dump the object.
+{en_US Run a Perinci::CmdLine-based script but only to dump the object}.
 
+{en_US 
 This function runs a CLI script that uses C<Perinci::CmdLine> (or its variant
 C<Perinci::CmdLine::Lite> or C<Perinci::CmdLine::Any>) but monkey-patches
 C<Perinci::CmdLine::Base> beforehand so that C<run()> will dump the object and
@@ -167,6 +169,7 @@ that script refers to function URL C</main> (which might mean that function
 metadata is embedded in the script itself and not in a separate module), will
 also dump the target function's metadata in C<func.meta> in this function's
 result metadata.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -174,16 +177,14 @@ Arguments ('*' denotes required arguments):
 
 =item * B<filename>* => I<str>
 
-Path to the script.
+{en_US Path to the script}.
 
-=item * B<libs> => I<array>
+=item * B<libs> => I<array[str]>
 
-Libraries to unshift to @INC when running script.
+{en_US Libraries to unshift to @INC when running script}.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -193,7 +194,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -217,7 +218,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
